Credits
=======

This module uses Open Source components.
You can find the source code of their projects along with license information below.
We acknowledge and are grateful to these developers for their contributions.

Antlr
-----

| Home Page: `antlr.org <https://www.antlr.org>`_
| License: `The BSD License <https://www.antlr.org/license.html>`_

JSON Grammar
------------

Used as base of jertl mini-language

| File: `json.g4 <https://github.com/antlr/grammars-v4/blob/master/json/JSON.g4>`_
| Repository: `antlr <https://github.com/antlr>`_ / `grammars-g4 <https://github.com/antlr/grammars-v4>`_

dataclasses
-----------

Backport of dataclasses required to use jertl in Python 3.6

| Home Page: `github <https://github.com/ericvsmith/dataclasses>`_
| License: `Apache Software License <https://opensource.org/licenses/Apache-2.0>`_
